<?php

namespace Buyesrfolio\LeadTask\Policies;

use Litepie\User\Contracts\UserPolicy;
use Buyesrfolio\LeadTask\Models\LeadTask;

class LeadTaskPolicy
{

    /**
     * Determine if the given user can view the lead_task.
     *
     * @param UserPolicy $user
     * @param LeadTask $lead_task
     *
     * @return bool
     */
    public function view(UserPolicy $user, LeadTask $lead_task)
    {
        if ($user->canDo('lead_task.lead_task.view') && $user->isAdmin()) {
            return true;
        }

        return $lead_task->user_id == user_id() && $lead_task->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lead_task.
     *
     * @param UserPolicy $user
     * @param LeadTask $lead_task
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('lead_task.lead_task.create');
    }

    /**
     * Determine if the given user can update the given lead_task.
     *
     * @param UserPolicy $user
     * @param LeadTask $lead_task
     *
     * @return bool
     */
    public function update(UserPolicy $user, LeadTask $lead_task)
    {
        if ($user->canDo('lead_task.lead_task.edit') && $user->isAdmin()) {
            return true;
        }

        return $lead_task->user_id == user_id() && $lead_task->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lead_task.
     *
     * @param UserPolicy $user
     * @param LeadTask $lead_task
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LeadTask $lead_task)
    {
        return $lead_task->user_id == user_id() && $lead_task->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lead_task.
     *
     * @param UserPolicy $user
     * @param LeadTask $lead_task
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LeadTask $lead_task)
    {
        if ($user->canDo('lead_task.lead_task.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lead_task.
     *
     * @param UserPolicy $user
     * @param LeadTask $lead_task
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LeadTask $lead_task)
    {
        if ($user->canDo('lead_task.lead_task.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
