<?php

namespace Buyesrfolio\LeadTask\Providers;

use Illuminate\Support\ServiceProvider;

class LeadTaskServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'lead_task');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'lead_task');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerLeadTask();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerLeadTask()
    {
        $this->app->bind('lead_task', function($app) {
            return new LeadTask($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('LeadTask', 'Lavalite\LeadTask\Facades\LeadTask');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('buyesrfolio.lead_task', function ($app) {
            return $this->app->make('Buyesrfolio\LeadTask\LeadTask');
        });

                // Bind LeadTask to repository
        $this->app->bind(
            'Buyesrfolio\LeadTask\Interfaces\LeadTaskRepositoryInterface',
            \Buyesrfolio\LeadTask\Repositories\Eloquent\LeadTaskRepository::class
        );

        $this->app->register(\Buyesrfolio\LeadTask\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Buyesrfolio\LeadTask\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and lead_task's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'buyesrfolio.lead_task'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeLeadTask::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['buyesrfolio.lead_task'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('buyesrfolio/lead_task.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/lead_task')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/lead_task')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
